@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Tools_src_global_qttools_config_p_h_H
+#define QT_FEATURES_Tools_src_global_qttools_config_p_h_H
+
 #define QT_FEATURE_assistant 1
 
 #define QT_FEATURE_clang -1
@@ -6,8 +9,6 @@
 
 #define QT_FEATURE_qdoc -1
 
-#define QT_FEATURE_clangcpp -1
-
 #define QT_FEATURE_designer 1
 
 #define QT_FEATURE_distancefieldgenerator -1
@@ -28,3 +29,5 @@
 
 #define QT_FEATURE_qtplugininfo -1
 
+
+#endif // QT_FEATURES_Tools_src_global_qttools_config_p_h_H
